GoogleOauth2Services class

Google oauth2 services

Constructors

GoogleOauth2Services()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCustomInterceptorsForRefreshToken({required String tenantId, required String clientId, required String clientSecret, required String scope, required String email, required String password, required Future<String?> getToken(), required Future<void> saveToken(String token)}) → InterceptorsWrapper
Generate Refresh token when expired token By custom indicator If you want to generate refresh token when expired token in your app, you can use this method using Dio interceptors
login({required String tenantId, required String clientId, required String clientSecret, required String scope, required String email, required String password}) Future<Map<String, dynamic>>