getCustomInterceptorsForRefreshToken static method
InterceptorsWrapper
getCustomInterceptorsForRefreshToken({})
Generate Refresh token when expired token By custom indicator If you want to generate refresh token when expired token in your app, you can use this method using Dio interceptors
Implementation
//calling interceptor
static InterceptorsWrapper getCustomInterceptorsForRefreshToken({
required String tenantId,
required String clientId,
required String clientSecret,
required String scope,
required String email,
required String password,
required Future<String?> Function() getToken,
required Future<void> Function(String token) saveToken,
}) {
return FzGoogleOauth2Services.getCustomInterceptorsForRefreshToken(
tenantId: tenantId,
clientId: clientId,
clientSecret: clientSecret,
scope: scope,
email: email,
password: password,
getToken: getToken,
saveToken: saveToken,
);
}