CustomInterceptors class

Custom Dio Interceptor with token injection and refresh logic.

Constructors

CustomInterceptors({required Future<String> getToken()?, required Future<void> saveToken(String token)?, required Future<Map<String, dynamic>> refreshToken()?})

Properties

getToken Future<String> Function()?
final
hashCode int
The hash code for this object.
no setterinherited
refreshToken Future<Map<String, dynamic>> Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveToken Future<void> Function(String token)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onError(DioError err, ErrorInterceptorHandler handler) → void
Called when an exception was occurred during the request.
onRequest(RequestOptions options, RequestInterceptorHandler handler) → void
Called when the request is about to be sent.
onResponse(Response response, ResponseInterceptorHandler handler) → void
Called when the response is about to be resolved.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited